==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken.md <==
# AwsIdentityAccessManagementMfaToken


```text
aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken
```

```text
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')
```



| Illustration | AwsIdentityAccessManagementMfaToken | AwsIdentityAccessManagementMfaTokenCard | AwsIdentityAccessManagementMfaTokenGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken.png) | ![illustration for AwsIdentityAccessManagementMfaToken](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken.Local.png) | ![illustration for AwsIdentityAccessManagementMfaTokenCard](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaTokenCard.Local.png) | ![illustration for AwsIdentityAccessManagementMfaTokenGroup](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaTokenGroup.Local.png) |




## AwsIdentityAccessManagementMfaToken

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaToken
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaToken('AwsIdentityAccessManagementMfaToken', 'Aws Identity Access Management Mfa Token', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaToken
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaToken('AwsIdentityAccessManagementMfaToken', 'Aws Identity Access Management Mfa Token', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementMfaTokenCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaTokenCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaTokenCard('AwsIdentityAccessManagementMfaTokenCard', 'Aws Identity Access Management Mfa Token Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaTokenCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaTokenCard('AwsIdentityAccessManagementMfaTokenCard', 'Aws Identity Access Management Mfa Token Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementMfaTokenGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaTokenGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaTokenGroup('AwsIdentityAccessManagementMfaTokenGroup', 'Aws Identity Access Management Mfa Token Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaTokenGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaTokenGroup('AwsIdentityAccessManagementMfaTokenGroup', 'Aws Identity Access Management Mfa Token Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken.md <==
# AwsIdentityAccessManagementMfaToken


```text
aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken
```

```text
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')
```



| Illustration | AwsIdentityAccessManagementMfaToken | AwsIdentityAccessManagementMfaTokenCard | AwsIdentityAccessManagementMfaTokenGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken.png) | ![illustration for AwsIdentityAccessManagementMfaToken](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken.Local.png) | ![illustration for AwsIdentityAccessManagementMfaTokenCard](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaTokenCard.Local.png) | ![illustration for AwsIdentityAccessManagementMfaTokenGroup](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaTokenGroup.Local.png) |




## AwsIdentityAccessManagementMfaToken

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaToken
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaToken('AwsIdentityAccessManagementMfaToken', 'Aws Identity Access Management Mfa Token', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaToken
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaToken('AwsIdentityAccessManagementMfaToken', 'Aws Identity Access Management Mfa Token', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementMfaTokenCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaTokenCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaTokenCard('AwsIdentityAccessManagementMfaTokenCard', 'Aws Identity Access Management Mfa Token Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaTokenCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaTokenCard('AwsIdentityAccessManagementMfaTokenCard', 'Aws Identity Access Management Mfa Token Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementMfaTokenGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaTokenGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaTokenGroup('AwsIdentityAccessManagementMfaTokenGroup', 'Aws Identity Access Management Mfa Token Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementMfaTokenGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementMfaToken')

' renders the element
AwsIdentityAccessManagementMfaTokenGroup('AwsIdentityAccessManagementMfaTokenGroup', 'Aws Identity Access Management Mfa Token Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
